# -----------------------------------------------------------------------------
sub infSWVer
{
  ($thishost) = @_;

  if ($ver_colors eq "N")
  {
    $sw_color[$thishost]   = "white";
    $msg = sprintf("(dbamonrc Ver_Colors: = N - Informix version checking disabled)");
    &logit($msg,$thishost);
    return 1;
  }

  if ($sw_version[$thishost] eq "")
  {
    logit("(No Informix version info for this instance)",$thishost);
    return 1;
  }

  $ver = $sw_version[$thishost];

  chop($filedate = `date +%C%y.%m.%d `);
  chop($filetime = `date +%H:%M:%S `);

  #
  # Check to see if we've already created today's report
  #

  $rpt_file = "$rptdir/informix_ver/$filedate";
  if (system("ls -l $rpt_file > /dev/null 2>&1") != 0)
  {
    $msg = sprintf("Creating Informix Version report - $rpt_file");
    &logit($msg,$thishost);
    $rpt_flag = 1;
    $upgrade_count = 0;
    open (RPT_FILE,">$rpt_file") || &error_msg("Can't open output $rpt_file - $!");
    printf RPT_FILE "%s - %s\n",$filedate,$filetime;
    printf RPT_FILE "\nInformix Version Report - Instances in need of Informix Upgrade\n";
    printf RPT_FILE "\nInstance                        Current Version  Version Status\n";
    printf RPT_FILE "------------------------------  ---------------  --------------------------------------------\n";
  }

  #
  # Determine status
  #

  $sw_color[$thishost] = "gray";

  if (system("grep _${ver}_ /opt/dbamon/adm/informix_ver/good.txt > /dev/null 2>&1") == 0)
  {
    $sw_color[$thishost] = "lime";
    $msg = sprintf("OK");
    &logit($msg,$thishost);
    $vers = "Good";
  }

  if (system("grep _${ver}_ /opt/dbamon/adm/informix_ver/soso.txt  > /dev/null 2>&1") == 0)
  {
    $sw_color[$thishost] = "yellow";
    $msg = sprintf("... Running Informix %s - Version designated as SO-SO ...",$ver);
    &logit($msg,$thishost);
    $vers = "Known Problems With Workarounds";
  }

  if (system("grep _${ver}_ /opt/dbamon/adm/informix_ver/bad.txt  > /dev/null 2>&1") == 0)
  {
    $sw_color[$thishost] = "hotpink";
    $msg = sprintf("... Running Informix %s - Version designated as BAD ...",$ver);
    &logit($msg,$thishost);
    $vers = "Known CRITICAL Problems Without Workarounds";
  }

  if ($sw_color[$thishost] eq "gray")
  {
    $msg = sprintf("... Running Informix %s - Version not being tracked - Status unknown ...",$ver);
    &logit($msg,$thishost);
    $vers = "Unknown Informix Version";
  }

  #
  # Create report - if neccessary
  #

  if ($rpt_flag)
  {
    if ($sw_color[$thishost] eq "hotpink" || $sw_color[$thishost] eq "yellow") 
    {
      $upgrade_count++;
    }
    printf RPT_FILE "%-30s  %-15s  %s\n",$title[$thishost],$ver,$vers;
    if ($thishost == $high_host)
    {
      close(RPT_FILE);
      $msg = sprintf("Mailing Informix Version report - $rpt_file");
      &logit($msg,$thishost);
      system("cat $rpt_file | dbamon_mailer -m -s 'DBAmon | $upgrade_count Instances In Need Of Informix Upgrade' $report_email");
      $rpt_flag = 0;
    }
  }
}
# -----------------------------------------------------------------------------
1;
