# -----------------------------------------------------------------------------
sub sqlPerf
# -----------------------------------------------------------------------------
{
  #----
  #---- This routine uses stacked data
  #----

  ($thishost) = @_;

  my $debug_perf = 0; 

  my $this_line = ""; 
  my $perf_other_rows = ""; 
  my $perf_vlf_rows = ""; 
  my $perf_event_count = 0; 
  my $this_perf_label = ""; 
  my $zlabel = ""; 
  my $zdesc = ""; 
  my $zwarn = ""; 
  my $zcrit = ""; 
  my $zoperator = ""; 
  my $zthresholds = ""; 

  my $perf_val     = ""; 
  my $perf_val_int = -1;
  my $perf_val_alpha = -1;

  my $zeventsev = ""; 

  $this_metric = ""; 
  $zshort_c = ""; 
  $zshort_w = ""; 

  if ($up[$thishost] ne "Y")
  {
    &logit("(Down/Inhibited)",$thishost);
    return 1;
  }

  if (&check_inhib($thishost) eq "Y")
  {
    $up[$thishost] = "I";
    return;
  }

  #---- Add some metrics that were previously saved in variables
  $perf_readings[$thishost]{"SYS_MemUsedPct"}        = $mem_pct[$thishost] if $mem_pct[$thishost] > 0;
  $perf_readings[$thishost]{"DBA_Instance_Dur_Secs"} = $instance_duration[$thishost] if $instance_duration[$thishost] > 0;
  if ($perf_readings[$thishost]{"SQL_TotMemKB"} > 0 && $perf_readings[$thishost]{"SQL_DBSizeKB"} > 0) 
  {
    $perf_readings[$thishost]{"SQL_SQLMem_Vs_DBSize_Pct"} = sprintf("%.2f", ($perf_readings[$thishost]{"SQL_TotMemKB"} / $perf_readings[$thishost]{"SQL_DBSizeKB"}) * 100); 
  }
  $perf_readings[$thishost]{"SQL_Signal_Wait_Pct"} = $mssql_perf_signal_wait_pct[$thishost];
  $perf_readings[$thishost]{"SQL_TempDB_File_Count"} = $mssql_tempdb_dfcount[$thishost]; 

  #---- Clear vars
  my $drilldown_data = ""; 

  foreach $this_metric (sort {lc($a) cmp lc($b)} keys %{ $perf_readings[$thishost] })
  {
    $perf_val = $perf_readings[$thishost]{$this_metric}; 
    $perf_val_int = -1; 

    #---- 5.40.A - Try to trim to just 2 decimal places - only if it is numeric
    #---- Old
    ## $perf_val = sprintf("%.2f", $perf_val) unless $perf_val =~ /[a-z]/i;
    #---- New
    if ($perf_val =~ /[a-z]/i) { $perf_val_alpha = 1; } 
    else                       { $perf_val_alpha = 0; } 
    if ($perf_val_alpha == 0) 
    {
      $perf_val = sprintf("%.2f", $perf_val); 
      #---- Integer value for the event short text
      $perf_val_int = int($perf_val); 
    }

    print "DEBUG sqlPerf - Found this_metric=($this_metric) perf_val=$perf_val pref_val_int=$perf_val_int perf_val_alpha=$perf_val_alpha\n" if $debug_perf; 

    $met_key = uc "PERF_$this_metric"; 

    #---- Insert the metrics row
    if ($perf_val_alpha == 0) 
    {
      &metricsInsert("sqlPerf()", $thishost, "$met_key", ".", $perf_val);
    }
    else
    {
      &metricsInsert("sqlPerf()", $thishost, "$met_key", "$perf_val", 1);
    }

    if ($this_metric =~ /rate/i || $this_metric =~ /persec/i) 
    {
      $zdesc = "Rate Per Second";
    }
    elsif ($this_metric =~ /_sis$/i) 
    {
      $zdesc = "Since Instance Start";
    }
    else
    {
      $zdesc = "Current Value";
    }

    &metricsCurrent("sqlPerf()",$thishost,"$met_key","",$perf_val,"","","$zdesc" );

    $this_metric_uc = uc $this_metric; 

    $zwarn = $t_perf_w[$thishost]{$this_metric_uc};
    $zcrit = $t_perf_c[$thishost]{$this_metric_uc};
    $zoperator = $t_perf_operator[$thishost]{$this_metric_uc};
    $zthresholds = "$zwarn/$zcrit"; 
    $zthresholds = " &nbsp; " if $zthresholds eq "/"; 
    $zeventsev = $t_perf_eventsev[$thishost]{$this_metric_uc};

    #---- Decide on what we will do for PERF EVENT Severity
    if ($zeventsev eq "C") 
    {
      $sqlperf_sev_w = "W"; 
      $sqlperf_sev_c = "C"; 
    }
    elsif ($g_sqlperf_sev eq "Y") 
    {
      $sqlperf_sev_w = "P"; 
      $sqlperf_sev_c = "P"; 
    }
    else
    {
      $sqlperf_sev_w = "W"; 
      $sqlperf_sev_c = "C"; 
    }

    if ($t_perf_operator[$thishost]{$this_metric_uc})  #---- The OPERATOR would have a value if this one was specified
    {

      #---- Find label from DBC for this metric (if any)
      if ($perf_metric_label[$thishost]{$this_metric})
      {
	$zlabel          = "($perf_metric_label[$thishost]{$this_metric})" ; 
      }
      else
      {
	$zlabel          = ""; 
      }

      #---- Create event details file, just in case
      open(TMPFL2, ">$tmpfl2") || &error_msg("Cannot open output $tmpfl2 - $!");
      print TMPFL2 "MSSQL Performance Metric Exception:

MSSQL_Perf_Metric: $this_metric_uc $zlabel
Current_Reading:   $perf_val 
Comparision_Oper:  $zoperator 
W_Threshold:       $zwarn
C_Threshold:       $zcrit
      "; 
      close(TMPFL2); 

      #---- Create short text messages, just in case
      if ($zeventsev eq "C") 
      {
        #---- For events that could become tickets (zeventsev=C), we want a more generic short text message
        $zshort_w = "MSSQL_Perf_Metric $this_metric $zlabel Exception - $zoperator WarningThreshold=$zwarn";
        $zshort_c = "MSSQL_Perf_Metric $this_metric $zlabel Exception - $zoperator CriticalThreshold=$zcrit";
      }
      else
      {
        #---- For events that could NOT become tickets (zeventsev=C), we want a detailed short text message
        $zshort_w = "MSSQL_Perf_Metric $this_metric=$perf_val_int $zlabel - $zoperator WarningThreshold=$zwarn";
        $zshort_c = "MSSQL_Perf_Metric $this_metric=$perf_val_int $zlabel - $zoperator CriticalThreshold=$zcrit";
      }

      #---- LT LOGIC -- Check current reading against threshold 
      if ($t_perf_operator[$thishost]{$this_metric_uc} eq "LT")  #---- The OPERATOR would have a value if this one was specified
      {
	if ($perf_val < $t_perf_c[$thishost]{$this_metric_uc})
	{
	  ##&event($sqlperf_sev_c,$thishost, $zshort_c,"Perf-${this_metric}","DBA852", $tmpfl2);
	  &sqlPerfEvent($sqlperf_sev_c, $zshort_c); 

	  $zcolor = "pink"; $perf_event_count++; 
	}
	elsif ($perf_val < $t_perf_w[$thishost]{$this_metric_uc})
	{
	  ##&event($sqlperf_sev_w,$thishost, $zshort_w,"Perf-${this_metric}","DBA852", $tmpfl2);
	  &sqlPerfEvent($sqlperf_sev_w, $zshort_w); 

	  $zcolor = "yellow"; $perf_event_count++; 
	}
	else { $zcolor = "lime"; }
      }
      #---- LE LOGIC -- Check current reading against threshold 
      elsif ($t_perf_operator[$thishost]{$this_metric_uc} eq "LE")  #---- The OPERATOR would have a value if this one was specified
      {
	if ($perf_val <= $t_perf_c[$thishost]{$this_metric_uc})
	{
	  ##&event($sqlperf_sev_c,$thishost, $zshort_c,"Perf-${this_metric}","DBA852", $tmpfl2);
	  &sqlPerfEvent($sqlperf_sev_c, $zshort_c); 

	  $zcolor = "pink"; $perf_event_count++; 
	}
	elsif ($perf_val <= $t_perf_w[$thishost]{$this_metric_uc})
	{
	  ##&event($sqlperf_sev_w,$thishost, $zshort_w,"Perf-${this_metric}","DBA852", $tmpfl2);
	  &sqlPerfEvent($sqlperf_sev_w, $zshort_w); 

	  $zcolor = "yellow"; $perf_event_count++; 
	}
	else { $zcolor = "lime"; }
      }
      #---- GT LOGIC -- Check current reading against threshold 
      elsif ($t_perf_operator[$thishost]{$this_metric_uc} eq "GT")  #---- The OPERATOR would have a value if this one was specified
      {
	if ($perf_val > $t_perf_c[$thishost]{$this_metric_uc})
	{
	  ##&event($sqlperf_sev_c,$thishost, $zshort_c,"Perf-${this_metric}","DBA852", $tmpfl2);
	  &sqlPerfEvent($sqlperf_sev_c, $zshort_c); 

	  $zcolor = "pink"; $perf_event_count++; 
	}
	elsif ($perf_val > $t_perf_w[$thishost]{$this_metric_uc})
	{
	  ##&event($sqlperf_sev_w,$thishost, $zshort_w,"Perf-${this_metric}","DBA852", $tmpfl2);
	  &sqlPerfEvent($sqlperf_sev_w, $zshort_w); 

	  $zcolor = "yellow"; $perf_event_count++; 
	}
	else { $zcolor = "lime"; }
      }
      #--- ELSE - Must be GE 
      else
      {
	if ($perf_val >= $t_perf_c[$thishost]{$this_metric_uc})
	{
	  ##&event($sqlperf_sev_c,$thishost, $zshort_c ,"Perf-${this_metric}","DBA852", $tmpfl2);
	  &sqlPerfEvent($sqlperf_sev_c, $zshort_c); 

	  $zcolor = "pink"; $perf_event_count++; 
	}
	elsif ($perf_val >= $t_perf_w[$thishost]{$this_metric_uc})
	{
	  ##&event($sqlperf_sev_w,$thishost, $zshort_w ,"Perf-${this_metric}","DBA852", $tmpfl2);
	  &sqlPerfEvent($sqlperf_sev_w, $zshort_w); 

	  $zcolor = "yellow"; $perf_event_count++; 
	}
	else { $zcolor = "lime"; }
      }
    }
    else
    {
      #---- No threshold was specified for this metric
      $zcolor = "white"; 
    }

    #---- Find label from DBC for this metric (if any)
    if ($perf_metric_label[$thishost]{$this_metric})
    {
      $this_perf_label = "<br>($perf_metric_label[$thishost]{$this_metric})"; 
      $zlabel          = $perf_metric_label[$thishost]{$this_metric}; 
    }
    else
    {
      $this_perf_label = ""; 
      $zlabel          = ""; 
    }
  
    #---- Format WWW page entry: 

    $this_metric_prefix = (split(/\_/,$this_metric)) [0];
    
    if ($this_metric_prefix ne $last_metric_prefix) 
    {
      if    ($this_metric_prefix eq "DBA") { $this_desc = "DBAmon Monitoring Performance"; } 
      elsif ($this_metric_prefix eq "SQL") { $this_desc = "MSSQL Database"; } 
      elsif ($this_metric_prefix eq "NET") { $this_desc = "Network"; } 
      elsif ($this_metric_prefix eq "SYS") { $this_desc = "Operating System/Server"; } 
      else                                 { $this_desc = ""; } 
      
      $drilldown_data .=  "<tr><td colspan=6> $f_s <p> &nbsp; <b> $this_metric_prefix $this_desc Performance Metric(s): </b> <br>\n"; 
    }
    $last_metric_prefix = $this_metric_prefix;

    ##  <td bgcolor=$zcolor>$f_s <b> $this_metric $this_perf_label </b>
    $drilldown_data .=  "<tr bgcolor=$table_rowcolor>
      <td bgcolor=$zcolor>$f_s <b> $met_key $this_perf_label </b>
      <td bgcolor=$zcolor align=right>$f_s <b> $perf_val </b>
      <td bgcolor=$zcolor align=right>$f_s <b> $zoperator $zthresholds $zeventsev </b> 
      <td>$f_s $zdesc 
      <td>$f_s &nbsp; Charts - Recent: 
               <a href='/cgi-bin/dbamon_metrics.pl?$mode,GRAW,$titleraw[$thishost],$met_key,.,$g_detail_retain_days,$zlabel'>   <b>L${g_detail_retain_days}D</b></a>  
               <a href='/cgi-bin/dbamon_metrics.pl?$mode,GRAW,$titleraw[$thishost],$met_key,.,10,$zlabel'>                      <b>L10D</b></a>  
               <a href='/cgi-bin/dbamon_metrics.pl?$mode,GRAW,$titleraw[$thishost],$met_key,.,7,$zlabel'>                       <b>L7D</b></a>  
               <a href='/cgi-bin/dbamon_metrics.pl?$mode,GRAW,$titleraw[$thishost],$met_key,.,3,$zlabel'>                       <b>L3D</b></a>  
               <a href='/cgi-bin/dbamon_metrics.pl?$mode,GRAW,$titleraw[$thishost],$met_key,.,2,$zlabel'>                       <b>L2D</b></a>  
               <a href='/cgi-bin/dbamon_metrics.pl?$mode,GRAW,$titleraw[$thishost],$met_key,.,1,$zlabel'>                       <b>L1D</b></a>  
               &nbsp;  Historical: 
               <a href='/cgi-bin/dbamon_metrics.pl?$mode,GDAILY,$titleraw[$thishost],$met_key,.'> <b>Daily</b></a> &nbsp;
      <td>$f_s &nbsp; Text/CSV - Recent: 
               <a href='/cgi-bin/dbamon_metrics.pl?$mode,MDETAIL,$titleraw[$thishost],$met_key,.'><b>L${g_detail_retain_days}D</b></a> &nbsp; 
               Historical: 
               <a href='/cgi-bin/dbamon_metrics.pl?$mode,MDAILY,$titleraw[$thishost],$met_key,.'><b>Daily</b></a> &nbsp;
    "; 
    #          <a href='/cgi-bin/dbamon_metrics.pl?$mode,GHOURLY,$titleraw[$thishost],$met_key,.'><b>Hourly (H)</b></a> &nbsp;
    #          <a href='/cgi-bin/dbamon_metrics.pl?$mode,MHOURLY,$titleraw[$thishost],$met_key,.'><b>Hourly (H)</b></a> &nbsp;

    #---- Save some possible readings for later (summarize.pl)
    if    ($this_metric eq "SYS_CPUTotalBusyPct")     { $reading_cpubusy_pct[$thishost]      = $perf_val; }
    elsif ($this_metric eq "SYS_MemUsedPct")          { $reading_memused_pct[$thishost]      = $perf_val; }
    elsif ($this_metric eq "SYS_DiskPhysAvgQueueLen") { $reading_diskqueuelen_avg[$thishost] = $perf_val; }
    elsif ($this_metric eq "SYS_DiskPhysAvgRTMS")     { $reading_diskrt_avg[$thishost]       = $perf_val; }
    elsif ($this_metric eq "SQL_Top_Waits_Rank1")     { $reading_topwait[$thishost]          = $perf_val; }
    elsif ($this_metric eq "SQL_RateBatchReqsPerSec") { $reading_sqlBRPS[$thishost]          = $perf_val; }
    elsif ($this_metric eq "SQL_PageLifeExpectancy")  { $reading_sqlple[$thishost]           = $perf_val; }
    elsif ($this_metric eq "SQL_BufferCacheHitRatio") { $reading_sqlchr[$thishost]           = $perf_val; }
    elsif ($this_metric eq "SQL_Tables_Count")        { $reading_sqltbls[$thishost]          = $perf_val; $tblcount[$thishost] = int($perf_val); }
    elsif ($this_metric eq "SQL_Tables_MRows")        { $reading_sqlrows[$thishost]          = $perf_val; $rowcount[$thishost] = $perf_val; }

    #---- Process LPIM Flag
    if    ($this_metric eq "SQL_LPIM_Locked_KB")     
    {
      if ($perf_val > 0) { $mssql_lpim[$thishost] = "On"; } 
      else               { $mssql_lpim[$thishost] = "*Off*"; }
    }
  }

  #---- Event DBA857 - TEMPDB file count vs. CPU count

  my $this_tempdb_dfcount = $mssql_tempdb_dfcount[$thishost]; 
  my $this_cpucount       = $hw_processors[$thishost]; 

  if ($this_cpucount >= 4) { $this_optimum_dfcount = 4; }
  else                     { $this_optimum_dfcount = $this_cpucount; }

  &metricsInsert ("sqlPerf()",$thishost,"PERF_SQL_TEMPDB_FILE_COUNT",".",$this_tempdb_dfcount);
  &metricsCurrent("sqlPerf()",$thishost,"PERF_SQL_TEMPDB_FILE_COUNT","" ,$this_tempdb_dfcount ,"" , "","Count of TEMPDB DB files.");

  if ($this_tempdb_dfcount >= 1 &&
      $this_cpucount       >= 1 &&
      $this_tempdb_dfcount < $this_optimum_dfcount)
  {
    $ev_cat = "Perf"; 
    &event("P",$thishost,"TEMPDB DB File Count ($this_tempdb_dfcount) < CPU Count ($this_cpucount) - Optimum TEMPDB DB File Count: $this_optimum_dfcount","TEMPDB-File-Count","DBA857");
    $perf_event_count++; 
  }

  #---- Event DBA858 - MSSQL "Signal Wait" % 
  # http://blog.sqlauthority.com/2011/02/02/sql-server-signal-wait-time-introduction-with-simple-example-day-2-of-28/
  my $zcolor = ""; 

  my $this_signal_wait_pct = $mssql_perf_signal_wait_pct[$thishost];

  #---- Recalculate t_mssql_signal_wait_pct based on SQL version

  if ($sw_version[$thishost] =~ /^11/) { $t_mssql_signal_wait_pct = 40; } 
  else                                 { $t_mssql_signal_wait_pct = 25; } 

  if ($this_signal_wait_pct >= $t_mssql_signal_wait_pct) 
  {
    my $z_signal_wait_pct = int($this_signal_wait_pct); 
    $ev_cat = "Perf"; 
    &event("P",$thishost,"MSSQL Instance SIGNAL_WAIT_PCT=$z_signal_wait_pct (Threshold=${t_mssql_signal_wait_pct}%)","Signal-Wait-${z_signal_wait_pct}%","DBA858");
    $perf_event_count++; 
    $zcolor = "pink";  
  }
  else
  {
    $zcolor = "lime";  
  }
  $perf_other_rows .=  "<tr bgcolor=$table_rowcolor>
      <td >$f_s <b> Signal Wait %: </b>
      <td bgcolor=$zcolor align=right>$f_s <b> ${this_signal_wait_pct}% </b>
      <td align=right>$f_s <b> ${t_mssql_signal_wait_pct}% </b> 
      <td align=left >$f_s  
        The amount of time that executing T-SQL statements (statements currently in a thread) 
        are ready to consume CPU but have to wait because the CPU is currently working on another task. 
  "; 
  &metricsInsert ("sqlPerf()",$thishost,"PERF_SQL_SIGNAL_WAIT_PCT",".",$mssql_perf_signal_wait_pct[$thishost]);
  &metricsCurrent("sqlPerf()",$thishost,"PERF_SQL_SIGNAL_WAIT_PCT","" ,$mssql_perf_signal_wait_pct[$thishost] ,"" ,$t_mssql_signal_wait_pct,"Percent of Wait Time spent waiting for CPU.");

  #$perf_other_rows .=  "<tr>
  #    <td bgcolor=$zcolor>$f_s <b> Resource Wait %: </b>
  #    <td bgcolor=$zcolor align=right>$f_s <b> $mssql_perf_resource_wait_pct[$thishost] </b>
  #    <td bgcolor=$zcolor align=right>$f_s &nbsp; \n"; 

  #---- VLF Processing

  my $this_line = ""; 
  my $zvlf_event_data = ""; 
  my $zvlf_event_cnt = 0; 
  foreach $this_line (split('\n',$glob_vlf_data[$thishost]))
  {
    ## print "DEBUGPERF_VLF: $this_line\n"; 
    my @zwords = split(/\s/,$this_line); 
    my $this_vlf_db  = $zwords[0]; 
    my $this_vlf_cnt = $zwords[1]; 
    my $zvlf_color = ""; 
    my $zvlf_text  = ""; 

    &metricsInsert( "sqlPerf()",$thishost,"PERF_SQL_VLF_COUNT","$this_vlf_db", $this_vlf_cnt);
    &metricsCurrent("sqlPerf()",$thishost,"PERF_SQL_VLF_COUNT","$this_vlf_db", $this_vlf_cnt, "", $t_mssql_vlf_count[$thishost], "Number of TLOG Virtual Log Files for this DB" );

    if ($this_vlf_cnt >= $t_mssql_vlf_count[$thishost]) 
    {
      $zvlf_color = "pink"; 
      $zvlf_text  = "VLF Count of $this_vlf_cnt is equal to or greater than DBC value T_MSSQL_VLF_Count: $t_mssql_vlf_count[$thishost]"; 
      $zvlf_event_cnt++; 
      $zvlf_event_data .= "DB: $this_vlf_db  VLFCount: $this_vlf_cnt\n"; 
    }
    else
    {
      $zvlf_color = "lime"; 
      ##$zvlf_text  = "OK (Less than DBC T_MSSQL_VLF_Count: $t_mssql_vlf_count[$thishost])"; 
      $zvlf_text  = "OK"; 
    }
    $perf_vlf_rows .=  "<tr bgcolor=$table_rowcolor>
	<td >$f_s <a href='/cgi-bin/dbamon_metrics.pl?$mode,GRAW,$titleraw[$thishost],PERF_SQL_VLF_COUNT,$this_vlf_db'><b> $this_vlf_db </b></a> 
	<td align=right bgcolor=$zvlf_color>$f_s <b> $this_vlf_cnt </b> 
	<td bgcolor=$zvlf_color>$f_s <b> $zvlf_text </b>
    "; 
  }
  
  if ($zvlf_event_cnt > 0)
  {
    open(TMPFL2, ">$tmpfl2") || &error_msg("Cannot open output $tmpfl2 - $!");
    print TMPFL2 "MSSQL Databases with VLF (Virtual Log File) count > DBC T_MSSQL_VLF_Count: $t_mssql_vlf_count[$thishost]\n\n"; 
    print TMPFL2 $zvlf_event_data;
    ##print TMPFL2 "\n"; 
    close(TMPFL2); 
    $ev_cat = "Perf"; 
    &event("P",$thishost,"$zvlf_event_cnt MSSQL Database(s) VLF Count >= DBC Threshold: $t_mssql_vlf_count[$thishost]","VLF-Count-DBs=$zvlf_event_cnt","DBA859",$tmpfl2);
  }

  #---- WWW Details 

  &logDetails($thishost,"</table>");
  &logDetails($thishost,"<br><a name='sqlPerf'> <h3>MSSQL / Server Performance Readings</h3>");

  &logDetails($thishost,"( <a href='/cgi-bin/dbamon_metrics.pl?test,MDETAIL,$titleraw[$thishost]'><b>View All DBAmon Performance Metrics for $titleraw[$thishost]</b></a> )");

  &logDetails($thishost,"<p><table border=0 bgcolor=$table_bgcolor>");
  &logDetails($thishost,"<tr bgcolor=$table_headbgcolor>
    <th>$f_s Metric<br>(Label)
    <th>$f_s Current<br> Reading 
    <th>$f_s <a href='http://dbamon.com/config/dbc_mssql.shtml'>Comparison<br> Operator<br>Warning/Critical<br>Thresholds<br>EventSev<br>(DBC:<br> T_PerfCounter:)</a>
    <th>$f_s Description 
    <th>$f_s Charts
    <th>$f_s Text/CSV Reports
  ");

  # <th>$f_s Graphs<br>(H)istorical Summarized<br>-or-<br>(R)aw Unsummarized 
  # <th>$f_s Text/CSV Reports<br>(H)istorical Summarized<br>-or-<br>(R)aw Unsummarized 

  &logDetails($thishost,$drilldown_data); 
  &logDetails($thishost,"</table><hr>");

  &logDetails($thishost,"<br><h3>Other Performance Metrics</h3><table border=0 bgcolor=$table_bgcolor>");

  &logDetails($thishost,"<tr bgcolor=$table_headbgcolor>
    <th>$f_s Metric
    <th>$f_s Current<br> Reading 
    <th>$f_s Threshold 
    <th>$f_s Description 
  ");
  &logDetails($thishost,$perf_other_rows); 
  &logDetails($thishost,"</table><hr>");

  &logDetails($thishost,"<br><h3>MSSQL VLF (Virtual Log File) Counts By Database </h3>");
  &logDetails($thishost,"<h5>DBC T_MSSQL_VLF_Count: Value for this instance: $t_mssql_vlf_count[$thishost] </h5>");
  &logDetails($thishost,"<table border=0 bgcolor=$table_bgcolor>"); &logDetails($thishost,"<tr bgcolor=$table_headbgcolor> <th>$f_s DB Name <br>(Click for <br>Detail Historical Graph) <th>$f_s Current<br> VLF Count 
    <th>$f_s Status 
  ");
  &logDetails($thishost,$perf_vlf_rows); 
  &logDetails($thishost,"</table><hr>");

  &logit("OK - Total Performance Events this iteration: $perf_event_count",$thishost);

  return; 
}

# -----------------------------------------------------------------------------
sub sqlPerfEvent
# -----------------------------------------------------------------------------
{
  my $sp_sev    = $_[0]; 
  my $sp_string = $_[1]; 

  #---- New 2013/11/22 - See if this DBC has xx specified. 
  if ($dbc_parm[$thishost]{'perf_events_during_shifts'} ne "") 
  {
    #---- Only create this event IF the current target_shift is found in perf_events_during_shifts
    if ( index($dbc_parm[$thishost]{'perf_events_during_shifts'}, $target_shift[$thishost]) == -1) 
    {
      #---- The current shift on the target is NOT in the list of shifts during which we can create PERF events - Skip this one
      &logit("  (Since current shift at Target ($target_shift[$thishost]) is NOT in the list of shifts during which we can create PERF events ($dbc_parm[$thishost]{'perf_events_during_shifts'}) this PERF event will NOT be created - ($sp_string)",$thishost);
      return; 
    }
  }

  #---- New 2013/07/09
  $ev_chart_file = &eventGraphPerf($thishost, $this_metric);
  $ev_perf_metric = $this_metric; 

  $ev_cat = "Perf"; 
 
  #---- Old
  #&event($sp_sev, $thishost, $zshort_c, "Perf-${this_metric}", "DBA852", $tmpfl2);
  #---- New
  &event($sp_sev, $thishost, $sp_string, "Perf-${this_metric}", "DBA852", $tmpfl2);

  #---- If the event is published (not suppressed) then event.pl will clear $ev_chart_file. 
  #----   However, it is suppressed by event.pl (dup) then it will not be cleared. 
  #----   It won't hurt anything to clear it again now - that will prevent it from being
  #---    wrongly attached to the next P event. 
  $ev_chart_file = ""; 
}

# -----------------------------------------------------------------------------
1;
